from warp_beacon.mediainfo.abstract import MediaInfoAbstract

class AudioInfo(MediaInfoAbstract):
	def __init__(self, filename: str) -> None:
		super(AudioInfo, self).__init__(filename)
		if self.container:
			stream_list = self.container.streams.get(audio=0)
			if stream_list:
				stream = stream_list[0]
				time_base = stream.time_base
				self.duration = float(stream.duration * time_base)

	def get_finfo(self, except_info: tuple=()) -> dict:
		res = {}
		if "duration" not in except_info:
			res["duration"] = round(self.get_duration())
		if "filesize" not in except_info:
			res["filesize"] = AudioInfo.get_filesize(self.filename)
		return res


import os

from pymongo import MongoClient

class DBClient(object):
	client = None

	def __init__(self) -> None:
		self.client = MongoClient(
			host=os.environ.get("MONGODB_HOST", default='127.0.0.1'), 
			port=int(os.environ.get("MONGODB_PORT", default=27017)),
			username=os.environ.get("MONGODB_USER", default='root'),
			password=os.environ.get("MONGODB_PASSWORD", default="changeme")
		)

	def __del__(self) -> None:
		self.close()

	def close(self) -> None:
		if self.client:
			self.client.close()
			self.client = None


import os

import pickle

from warp_beacon.storage.mongo import DBClient
from warp_beacon.jobs.download_job import DownloadJob

import logging

class FailHandler(object):
	client = None
	db = None
	def __init__(self, client: DBClient) -> None:
		self.db = client.client.media.failed_jobs

	def __del__(self) -> None:
		self.client.close()

	def store_failed_job(self, job: DownloadJob) -> int:
		db_id = -1
		try:
			job_serilized = pickle.dumps(job)
			db_id = self.db.insert_one(
			{
				"job_data": job_serilized
			}).inserted_id
		except Exception as e:
			logging.error("Failed to store job as failed!")
			logging.exception(e)
		return db_id
	
	def get_failed_jobs(self) -> list:
		ret = []
		try:
			cursor = self.db.find()
			for document in cursor:
				ret.append(pickle.loads(document["job_data"]))
			self.db.delete_many({})
		except Exception as e:
			logging.error("Failed to get failed jobs!")
			logging.exception(e)
		return ret
